# Generated by Django 5.0 on 2024-01-13 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0015_season_hash'),
    ]

    operations = [
        migrations.AlterField(
            model_name='venue',
            name='address',
            field=models.CharField(blank=True, default=None, max_length=128, null=True, verbose_name='address'),
        ),
        migrations.AlterField(
            model_name='venue',
            name='city',
            field=models.CharField(blank=True, default=None, max_length=32, null=True, verbose_name='city'),
        ),
        migrations.AlterField(
            model_name='venue',
            name='country',
            field=models.CharField(blank=True, default=None, max_length=32, null=True, verbose_name='country'),
        ),
        migrations.AlterField(
            model_name='venue',
            name='name',
            field=models.CharField(max_length=128, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='venue',
            name='state',
            field=models.CharField(blank=True, default=None, max_length=32, null=True, verbose_name='state'),
        ),
        migrations.AlterField(
            model_name='venue',
            name='venue_id',
            field=models.CharField(max_length=40, verbose_name='venue ID'),
        ),
        migrations.AlterField(
            model_name='venue',
            name='zip_code',
            field=models.CharField(blank=True, default=None, max_length=10, null=True, verbose_name='ZIP Code'),
        ),
    ]
