# Generated by Django 5.0 on 2024-01-13 17:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0014_season_league'),
    ]

    operations = [
        migrations.AddField(
            model_name='season',
            name='hash',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='hash'),
        ),
    ]
