# Generated by Django 5.0 on 2024-01-14 14:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0016_alter_venue_address_alter_venue_city_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='gameperiod',
            name='sport_radar_period_id',
        ),
        migrations.AddField(
            model_name='gameperiod',
            name='end_date',
            field=models.DateField(blank=True, null=True, verbose_name='end date'),
        ),
        migrations.AddField(
            model_name='gameperiod',
            name='period_id',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='game period ID'),
        ),
        migrations.AddField(
            model_name='gameperiod',
            name='start_date',
            field=models.DateField(blank=True, null=True, verbose_name='start date'),
        ),
    ]
