# Generated by Django 5.0 on 2024-01-09 22:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0009_player_player_id'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='player',
            options={'ordering': ('team', 'last_name', 'first_name'), 'verbose_name': 'Player', 'verbose_name_plural': 'Players'},
        ),
        migrations.AddField(
            model_name='player',
            name='birth_date',
            field=models.DateField(blank=True, null=True, verbose_name='birth date'),
        ),
        migrations.AddField(
            model_name='player',
            name='height',
            field=models.CharField(blank=True, max_length=10, verbose_name='height'),
        ),
        migrations.AddField(
            model_name='player',
            name='jersey_number',
            field=models.CharField(blank=True, max_length=10, verbose_name='jersey number'),
        ),
        migrations.AddField(
            model_name='player',
            name='position',
            field=models.CharField(blank=True, max_length=10, verbose_name='position'),
        ),
        migrations.AddField(
            model_name='player',
            name='primary_position',
            field=models.CharField(blank=True, max_length=10, verbose_name='primary position'),
        ),
        migrations.AddField(
            model_name='player',
            name='weight',
            field=models.CharField(blank=True, max_length=10, verbose_name='weight'),
        ),
    ]
