# Generated by Django 5.0 on 2024-01-03 15:28

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0005_alter_sport_options_league'),
    ]

    operations = [
        migrations.AddField(
            model_name='conference',
            name='league',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='conferences', to='sports.league', verbose_name='League'),
        ),
    ]
