# Generated by Django 5.0 on 2024-01-03 14:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0004_sport'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='sport',
            options={'verbose_name': 'Sport', 'verbose_name_plural': 'Sports'},
        ),
        migrations.CreateModel(
            name='League',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=40, verbose_name='League Name')),
                ('sport', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='leagues', to='sports.sport', verbose_name='Sport')),
            ],
            options={
                'verbose_name': 'League',
                'verbose_name_plural': 'Leagues',
            },
        ),
    ]
