# Generated by Django 5.0 on 2024-01-10 20:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0012_season_season_id_alter_season_label'),
    ]

    operations = [
        migrations.RenameField(
            model_name='season',
            old_name='season_name',
            new_name='name',
        ),
        migrations.RenameField(
            model_name='season',
            old_name='season_type',
            new_name='type',
        ),
        migrations.AddField(
            model_name='season',
            name='end_date',
            field=models.DateField(blank=True, null=True, verbose_name='end date'),
        ),
        migrations.AddField(
            model_name='season',
            name='start_date',
            field=models.DateField(blank=True, null=True, verbose_name='start date'),
        ),
        migrations.AddField(
            model_name='season',
            name='year',
            field=models.CharField(default='', max_length=4, verbose_name='year'),
        ),
    ]
