# Generated by Django 5.0 on 2024-01-03 20:54

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0007_alter_conference_league'),
    ]

    operations = [
        migrations.CreateModel(
            name='Player',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('first_name', models.CharField(max_length=255, verbose_name='first name')),
                ('last_name', models.CharField(max_length=255, verbose_name='last name')),
                ('team', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sports.team')),
            ],
        ),
    ]
