# Generated by Django 5.0 on 2024-01-10 19:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0011_alter_player_height_alter_player_jersey_number_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='season',
            name='season_id',
            field=models.CharField(default=1, max_length=40, verbose_name='season id'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='season',
            name='label',
            field=models.CharField(blank=True, default=None, max_length=100, null=True, verbose_name='label'),
        ),
    ]
