# Generated by Django 5.0 on 2024-01-10 20:23

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0013_rename_season_name_season_name_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='season',
            name='league',
            field=models.ForeignKey(default=3, on_delete=django.db.models.deletion.CASCADE, related_name='seasons', to='sports.league', verbose_name='League'),
            preserve_default=False,
        ),
    ]
