# Generated by Django 5.0 on 2024-01-03 14:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0002_team_alias'),
    ]

    operations = [
        migrations.AddField(
            model_name='venue',
            name='address',
            field=models.CharField(blank=True, default='', max_length=128, verbose_name='address'),
        ),
    ]
