# Generated by Django 5.0 on 2024-01-03 14:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0003_venue_address'),
    ]

    operations = [
        migrations.CreateModel(
            name='Sport',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=40, verbose_name='Sport Name')),
            ],
        ),
    ]
