# Generated by Django 5.0 on 2024-01-14 16:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0017_remove_gameperiod_sport_radar_period_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='gameperiod',
            name='label',
            field=models.CharField(blank=True, default=None, max_length=100, null=True, verbose_name='label'),
        ),
    ]
