# Generated by Django 5.0 on 2024-01-03 21:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0008_player'),
    ]

    operations = [
        migrations.AddField(
            model_name='player',
            name='player_id',
            field=models.CharField(default=123, max_length=40),
            preserve_default=False,
        ),
    ]
